@@ -65,9 +65,9 @@ using namespace CPlusPlus;
 
 struct ScanResult
 {
-    char *fileName;
-    unsigned int size;
-    int flags;
+    char *fileName = nullptr;
+    int size = 0;
+    int flags = 0;
 };
 
 struct Opaq
@@ -126,7 +126,7 @@ public:
     {
     }
 
-    bool equals(const Token &tk, const QLatin1Literal &literal) const
+    bool equals(const Token &tk, const QLatin1String &literal) const
     {
         return static_cast<int>(tk.length()) == literal.size()
                 && memcmp(m_fileContent + tk.begin(), literal.data(), literal.size()) == 0;
@@ -136,13 +136,13 @@ public:
 static void scanCppFile(void *opaq, CPlusPlus::Lexer &yylex, bool scanForFileTags,
                         bool scanForDependencies)
 {
-    const QLatin1Literal includeLiteral("include");
-    const QLatin1Literal importLiteral("import");
-    const QLatin1Literal defineLiteral("define");
-    const QLatin1Literal qobjectLiteral("Q_OBJECT");
-    const QLatin1Literal qgadgetLiteral("Q_GADGET");
-    const QLatin1Literal qnamespaceLiteral("Q_NAMESPACE");
-    const QLatin1Literal pluginMetaDataLiteral("Q_PLUGIN_METADATA");
+    const QLatin1String includeLiteral("include");
+    const QLatin1String importLiteral("import");
+    const QLatin1String defineLiteral("define");
+    const QLatin1String qobjectLiteral("Q_OBJECT");
+    const QLatin1String qgadgetLiteral("Q_GADGET");
+    const QLatin1String qnamespaceLiteral("Q_NAMESPACE");
+    const QLatin1String pluginMetaDataLiteral("Q_PLUGIN_METADATA");
     const auto opaque = static_cast<Opaq *>(opaq);
     const TokenComparator tc(opaque->fileContent);
     Token tk;
@@ -163,7 +163,7 @@ static void scanCppFile(void *opaq, CPlusPlus::Lexer &yylex, bool scanForFileTag
                     yylex.setScanAngleStringLiteralTokens(false);
 
                     if (!tk.newline() && (tk.is(T_STRING_LITERAL) || tk.is(T_ANGLE_STRING_LITERAL))) {
-                        scanResult.size = tk.length() - 2;
+                        scanResult.size = int(tk.length() - 2);
                         if (tk.is(T_STRING_LITERAL))
                             scanResult.flags = SC_LOCAL_INCLUDE_FLAG;
                         else
@@ -226,15 +226,15 @@ static void *openScanner(const unsigned short *filePath, const char *fileTags, i
         return nullptr;
     }
 
-    struct stat s;
+    struct stat s{};
     int r = fstat(opaque->fd, &s);
     if (r != 0)
         return nullptr;
     mapl = s.st_size;
     opaque->mapl = mapl;
 
-    void *vmap = mmap(0, s.st_size, PROT_READ, MAP_PRIVATE, opaque->fd, 0);
-    if (vmap == MAP_FAILED)
+    void *vmap = mmap(nullptr, s.st_size, PROT_READ, MAP_PRIVATE, opaque->fd, 0);
+    if (vmap == MAP_FAILED) // NOLINT(cppcoreguidelines-pro-type-cstyle-cast)
         return nullptr;
 #else
     opaque->file.setFileName(opaque->fileName);
@@ -248,6 +248,16 @@ static void *openScanner(const unsigned short *filePath, const char *fileTags, i
         return nullptr;
 
     opaque->fileContent = reinterpret_cast<char *>(vmap);
+
+    // Check for UTF-8 Byte Order Mark (BOM). Skip if found.
+    if (mapl >= 3
+            && opaque->fileContent[0] == char(0xef)
+            && opaque->fileContent[1] == char(0xbb)
+            && opaque->fileContent[2] == char(0xbf)) {
+        opaque->fileContent += 3;
+        mapl -= 3;
+    }
+
     CPlusPlus::Lexer lex(opaque->fileContent, opaque->fileContent + mapl);
     scanCppFile(opaque.get(), lex, flags & ScanForFileTagsFlag, flags & ScanForDependenciesFlag);
     return opaque.release();
@@ -301,7 +311,7 @@ static const char **additionalFileTags(void *opaq, int *size)
 ScannerPlugin includeScanner =
 {
     "include_scanner",
-    "hpp,cpp,cpp_pch_src,c,c_pch_src,objcpp,objcpp_pch_src,objc,objc_pch_src",
+    "cpp,cpp_pch_src,c,c_pch_src,objcpp,objcpp_pch_src,objc,objc_pch_src,rc",
     openScanner,
     closeScanner,
     next,
@@ -309,7 +319,7 @@ ScannerPlugin includeScanner =
     ScannerUsesCppIncludePaths | ScannerRecursiveDependencies
 };
 
-ScannerPlugin *cppScanners[] = { &includeScanner, NULL };
+ScannerPlugin *cppScanners[] = { &includeScanner, nullptr };
 
 static void QbsCppScannerPluginLoad()
 {
@@ -320,6 +330,6 @@ static void QbsCppScannerPluginUnload()
 {
 }
 
-QBS_REGISTER_STATIC_PLUGIN(extern "C" CPPSCANNER_EXPORT, QbsCppScannerPlugin,
+QBS_REGISTER_STATIC_PLUGIN(extern "C" CPPSCANNER_EXPORT, qbs_cpp_scanner,
                            QbsCppScannerPluginLoad, QbsCppScannerPluginUnload)
 
